"""
A package containing multiple general use utilities for free use.
"""
__author__ = 'Taylor "Nekroze" Lawson'
__email__ = 'tlawson@nekroze.com'
__version__ = '0.5.0'
